@@ -28,6 +28,7 @@ class TnoActionPlanView(ActionPlan):
     grok.template('actionplan')
     grok.name('index_html')
 
-    question_filter = sql.or_(
-            model.MODULE_WITH_RISK_FILTER,
-            model.RISK_PRESENT_FILTER)
+    question_filter = sql.and_(
+            model.RISK_OR_MODULE_WITH_DESCRIPTION_FILTER,
+            sql.or_(model.MODULE_WITH_RISK_FILTER,
+                    model.RISK_PRESENT_FILTER))
